summaryrefslogtreecommitdiffstats
path: root/src/H5ESpublic.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5ESpublic.h')
-rw-r--r--src/H5ESpublic.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/H5ESpublic.h b/src/H5ESpublic.h
index 2df1a6e..e3b1b56 100644
--- a/src/H5ESpublic.h
+++ b/src/H5ESpublic.h
@@ -29,7 +29,7 @@ typedef enum H5ES_status_t {
H5ES_STATUS_IN_PROGRESS, /* Operation has not yet completed */
H5ES_STATUS_SUCCEED, /* Operation has completed, successfully */
H5ES_STATUS_FAIL, /* Operation has completed, but failed */
- H5ES_STATUS_CANCELLED /* Operation has not completed and was cancelled */
+ H5ES_STATUS_CANCELED /* Operation has not completed and was canceled */
} H5ES_status_t;